@@ -38,6 +38,7 @@
 #include "debugger_m88xx0.h"
 #include "ascii_ctype.h"
 #include "hostcom.h"
+#include "logger.h"
 #include "mainapp.h"
 #include "memdump.h"
 #include "mystring.h"
@@ -138,6 +139,7 @@ Debugger::Init()
 		return false;
 	}
 
+	logger = gMainApp.GetLogger();
 	syncer = GetSyncer();
 
 	try {
@@ -274,7 +276,7 @@ Debugger::ThreadRun()
 		}
 	}
 
-	LeavePrompt(false);
+	QuitPrompt();
 	Close();
 }
 
@@ -463,7 +465,7 @@ Debugger::Input(int c)
 				break;
 			 case CmdAct::Quit:
 				// アプリケーション自体を終了
-				LeavePrompt(false);
+				QuitPrompt();
 				gMainApp.GetUIMessage()->Post(UIMessage::APPEXIT);
 			}
 		} else if (c < ' ' || c == 0x07f) {
@@ -484,6 +486,9 @@ Debugger::EnterPrompt()
 {
 	is_prompt = true;
 
+	// プロンプト中はログをシリアライズ。
+	logger->SetSerialize(true);
+
 	// ブレークポイント到達メッセージがあればここで表示
 	if (bpointmsg.empty() == false) {
 		fprintf(cons, "%s", bpointmsg.c_str());
@@ -499,6 +504,16 @@ Debugger::EnterPrompt()
 	PrintPrompt();
 }
 
+// コマンドモード(プロンプト)から出る。終了用。
+void
+Debugger::QuitPrompt()
+{
+	// 終了までの間 VM の実行が進んでしまわないよう停止指示を出しておく。
+	scheduler->Terminate();
+
+	LeavePrompt(false);
+}
+
 // コマンドモード(プロンプト)から出る。
 // trace はプロンプトから抜ける際のトレース状態の指示。
 // スレッド終了時は false を指定すること。
@@ -510,6 +525,9 @@ Debugger::LeavePrompt(bool trace)
 
 	is_prompt = false;
 
+	// ログを非同期に戻す。
+	logger->SetSerialize(false);
+
 	// 最後に VM スレッドで待機している Exec() を起こす
 	{
 		std::lock_guard<std::mutex> lock(mtx);
@@ -917,6 +935,7 @@ Debugger::ReadBreakpointInst(breakpoint_t& bp)
 	{ "mpu",	&Debugger::cmd_mpu,		},
 	{ "n",		&Debugger::cmd_n,		},
 	{ "nt",		&Debugger::cmd_nt,		},
+	{ "pe",		&Debugger::cmd_pe,		},
 	{ "q",		&Debugger::cmd_q,		},
 	{ "quit",	&Debugger::cmd_q,		},
 	{ "reset",	&Debugger::cmd_reset,	},
@@ -1062,6 +1081,7 @@ Debugger::HelpListMain = {
 	{ "L",		"Set log level" },
 	{ "m/M",	"Memory dump" },
 	{ "n/nt",	"Step until next instruction (Skip subroutines)" },
+	{ "pe",		"Print exception frame" },
 	{ "quit",	"Quit" },
 	{ "r*",		"Show registers (Type \"hr\" for details)" },
 	{ "reset",	"Reset the VM" },
@@ -1297,6 +1317,14 @@ Debugger::HelpDetails = {
 	)**" },
 	{ "nt", "=n" },
 
+	//-----
+	{ "pe", R"**(
+	Command: pe [<address>]
+
+	Print an exception frame starting with <address>.  If the <address> is
+	omitted, %sp is used.
+	)**" },
+
 	//-----
 	{ "quit", R"**(
 	Command: quit (or q)
@@ -1666,6 +1694,7 @@ Debugger::AddBreakInst(const std::string& cpustr, const std::string& argstr,
 {
 	DebuggerMD *md;
 	breakpoint_t bp;
+	std::string hexstr;
 	std::string inststr;
 	std::string maskstr;
 	int instlen;
@@ -1681,19 +1710,19 @@ Debugger::AddBreakInst(const std::string& cpustr, const std::string& argstr,
 
 	// 命令部。
 	// ニーモニックが指定できたら便利。
-	inststr = md->ParseInst(argstr);
-	if (inststr.empty() == false) {
+	hexstr = md->ParseInst(argstr);
+	if (hexstr.empty()) {
 		masklen = -1;
 	} else {
-		auto pos = argstr.find(':');
+		auto pos = hexstr.find(':');
 		if (pos == std::string::npos) {
 			// マスク指定なし。
-			inststr = argstr;
+			inststr = hexstr;
 			masklen = -1;
 		} else {
 			// マスク指定あり。
-			inststr = argstr.substr(0, pos);
-			maskstr = argstr.substr(pos + 1);
+			inststr = hexstr.substr(0, pos);
+			maskstr = hexstr.substr(pos + 1);
 			masklen = maskstr.size();
 		}
 	}
@@ -2753,6 +2782,28 @@ Debugger::SetNBreakpoint()
 	}
 }
 
+// 例外フレームを表示する。
+Debugger::CmdAct
+Debugger::cmd_pe()
+{
+	busaddr saddr;
+
+	saddr = busaddr(curmd->GetRegAddr("sp"));
+	if (cmdargs.size() > 1) {
+		if (GetAddr(&saddr, true) == false) {
+			return CmdAct::Stay;
+		}
+	}
+
+	// 例外フレームなのでスーパーバイザ、データ空間読み込み固定。
+	saddr |= BusAddr::SRead;
+	// 今のところ論理アドレスのみ(?)
+	saddr |= BusAddr::Logical;
+
+	curmd->PrintExceptionFrame(cons, saddr);
+	return CmdAct::Stay;
+}
+
 // デバッガ終了コマンド
 Debugger::CmdAct
 Debugger::cmd_q()
@@ -3127,3 +3178,9 @@ DebuggerMD::GetNextPC()
 	Disassemble(mem);
 	return mem.laddr.Addr();
 }
+
+void
+DebuggerMD::PrintExceptionFrame(FILE *out, busaddr)
+{
+	fprintf(out, "Not supported\n");
+}
