@@ -21,6 +21,7 @@
 
 class BranchHistory;
 class HostCOMDevice;
+class Logger;
 class MemdumpMonitor;
 class Syncer;
 class VectorTable;
@@ -123,6 +124,7 @@ class Debugger : public ThreadDevice
 	void AcceptCallback(uint32);
 	void Input(int);
 	void EnterPrompt();
+	void QuitPrompt();
 	void LeavePrompt(bool trace);
 	void PrintPrompt();
 
@@ -157,6 +159,7 @@ class Debugger : public ThreadDevice
 	CmdAct cmd_minus();
 	CmdAct cmd_n();
 	CmdAct cmd_nt();
+	CmdAct cmd_pe();
 	CmdAct cmd_q();
 	CmdAct cmd_reset();
 	CmdAct cmd_s();
@@ -271,6 +274,7 @@ class Debugger : public ThreadDevice
 	// ベクタテーブル
 	std::unique_ptr<VectorTable> pVectorTable /*{}*/;
 
+	Logger *logger {};
 	Syncer *syncer {};
 
 	static std::vector<cmddef_t> cmdtable;
