@@ -15,6 +15,7 @@
 #include "m680x0disasm.h"
 #include "m68030mmu.h"
 #include "mainbus.h"
+#include "vectortable.h"
 
 // コンストラクタ
 DebuggerMD_m680x0::DebuggerMD_m680x0(Debugger *parent_)
@@ -738,7 +739,313 @@ DebuggerMD_m680x0::Disassemble(DebuggerMemoryStream& mem)
 std::string
 DebuggerMD_m680x0::ParseInst(const std::string& inst) const
 {
+	if (inst == "nop")		return "4e71";
+	if (inst == "ptestr")	return "f0008200:ffc0e200";
+	if (inst == "ptestw")	return "f0008000:ffc0e200";
 	if (inst == "rte")		return "4e73";
 
 	return "";
 }
+
+// 例外フレーム処理用の便利クラス。
+// 例外フレーム内は基本ワード単位なのに、仕様書のオフセットはバイト単位
+// なのでこういうヘルパーがないと事故が多発する。
+class StackData
+{
+ public:
+	StackData(DebuggerMemoryStream& mem_)
+		: mem(mem_)
+	{
+		ReadWordUntil(4);
+	}
+
+	// 合計が words [ワード] になるまで追加で読み込む。
+	void ReadWordUntil(size_t words);
+
+	// 改行込みで出力。
+	void Print(FILE *out, size_t byteoffset, uint bytes, const char *text) const
+	{
+		fprintf(out, "%s\n", Format(byteoffset, bytes, text).c_str());
+	}
+
+	// 共通の表示用文字列を作成して返す。戻り値は改行なしの文字列。
+	std::string Format(size_t byteoffset, uint bytes, const char *text) const;
+
+	// byteoffset の位置のデータを表示用文字列にする。
+	std::string FormatWord(size_t byteoffset) const;
+	std::string FormatLong(size_t byteoffset) const;
+
+	// byteoffset の位置からのワードデータを返す。バスエラーなら -1。
+	uint32 Word(size_t byteoffset) const;
+	// byteoffset の位置からのロングワードを返す。バスエラーなら (uint64)-1。
+	uint64 Long(size_t byteoffset) const;
+
+	// データサイズをバイト単位で返す。
+	size_t bytesize() const noexcept { return framebuf.size() * 2; }
+
+ private:
+	DebuggerMemoryStream mem;
+	std::vector<uint32> framebuf {};
+};
+
+void
+StackData::ReadWordUntil(size_t words)
+{
+	while (framebuf.size() < words) {
+		framebuf.push_back(mem.Read(2));
+	}
+}
+
+// 共通の表示用文字列を作成して返す。戻り値は改行なしの文字列。
+std::string
+StackData::Format(size_t byteoffset, uint bytes, const char *text) const
+{
+	std::string s = string_format("+$%02x: ", (uint)byteoffset);
+
+	if (bytes == 2) {
+		s += FormatWord(byteoffset);
+	} else {
+		s += FormatLong(byteoffset);
+	}
+	// text があれば位置合わせした後に表示。
+	if (text) {
+		s += string_format("%*s : %s", 8 - bytes * 2, "", text);
+	}
+	return s;
+}
+
+// byteoffset の位置からのワードデータを表示用文字列にする。
+std::string
+StackData::FormatWord(size_t byteoffset) const
+{
+	uint32 data = Word(byteoffset);
+	if ((int32)data < 0) {
+		return "----";
+	} else {
+		char buf[16];
+		snprintf(buf, sizeof(buf), "%04x", data);
+		return buf;
+	}
+}
+
+// byteoffset の位置からのロングワードデータを表示用文字列にする。
+std::string
+StackData::FormatLong(size_t byteoffset) const
+{
+	uint64 data = Long(byteoffset);
+	if ((int64)data < 0) {
+		return "--------";
+	} else {
+		char buf[16];
+		snprintf(buf, sizeof(buf), "%08x", (uint32)data);
+		return buf;
+	}
+}
+
+uint32
+StackData::Word(size_t byteoffset) const
+{
+	size_t wordoffset = byteoffset / 2;
+	return framebuf[wordoffset];
+}
+
+uint64
+StackData::Long(size_t byteoffset) const
+{
+	uint32 hi = Word(byteoffset);
+	uint32 lo = Word(byteoffset + 2);
+	if ((int32)hi < 0 || (int32)lo < 0) {
+		return (uint64)-1;
+	}
+	return (hi << 16) | lo;
+}
+
+// 例外フレームを表示する。
+void
+DebuggerMD_m680x0::PrintExceptionFrame(FILE *out, busaddr addr)
+{
+	DebuggerMemoryStream mem(this, addr);
+	StackData frame(mem);
+
+	fprintf(out, "Exception stack at $%08x\n", addr.Addr());
+
+	frame.Print(out, 0, 2, "SR");
+	frame.Print(out, 2, 4, "PC");
+	// +6: Format|Vector
+	uint32 format_vector = frame.Word(6);
+	uint32 format = format_vector >> 12;
+	uint32 vector = (format_vector >> 2) & 0xff;
+	std::string s6 = frame.Format(6, 2, "");
+	s6 += string_format("Format=$%x Vector=$%02x", format, vector);
+	auto vectortable = GetVectorTable();
+	const char *exname = vectortable->GetExceptionName(vector);
+	if (exname) {
+		s6 += " \"";
+		s6 += exname;
+		s6 += '\"';
+	}
+	fprintf(out, "%s\n", s6.c_str());
+
+	// ここからフレーム別。
+	switch (format) {
+	 case 0x0:	// 034 Four word stack
+	 case 0x1:	// 034 Throwaway four word stack
+		// 追加ワードなし。
+		break;
+
+	 case 0x2:	// 034 Six word stack
+		PrintExceptionFrame2(out, frame);
+		break;
+
+	 case 0x3:	// --4 Floating-point post-instruction stack
+		PrintExceptionFrame3(out, frame);
+		break;
+
+	 case 0x4:	// --L Eight-word stack
+		PrintExceptionFrame4(out, frame);
+		break;
+
+	 case 0x7:	// --4 Access error stack
+		PrintExceptionFrame7(out, frame);
+		break;
+
+	 case 0xb:	// -3- Long bus cycle stack
+		PrintExceptionFrameB(out, frame);
+		break;
+
+	 case 9:	// -3- Coprocessor mid-instruction Stack
+	 case 0xa:	// -3- Short bus cycle stack (nono は生成しない)
+	 default:
+		fprintf(out, "Format $%x not supported\n", format);
+		break;
+	}
+}
+
+void
+DebuggerMD_m680x0::PrintExceptionFrame2(FILE *out, StackData& frame)
+{
+	frame.ReadWordUntil(6);
+	frame.Print(out, 0x08, 4, "(Next or this) instruction address");
+}
+
+void
+DebuggerMD_m680x0::PrintExceptionFrame3(FILE *out, StackData& frame)
+{
+	frame.ReadWordUntil(6);
+	frame.Print(out, 0x08, 4, "Effective Address");
+}
+
+void
+DebuggerMD_m680x0::PrintExceptionFrame4(FILE *out, StackData& frame)
+{
+	frame.ReadWordUntil(8);
+	frame.Print(out, 0x08, 4, "Effective Address");
+	frame.Print(out, 0x0c, 4, "PC of Faulted Instruction");
+}
+
+void
+DebuggerMD_m680x0::PrintExceptionFrame7(FILE *out, StackData& frame)
+{
+	static const char * const sizestr[] = {
+		".L",
+		".B",
+		".W",
+		"Line",
+	};
+
+	frame.ReadWordUntil(30);
+
+	frame.Print(out, 0x08, 4, "Effective Address");
+
+	// SSW
+	std::string sswbuf = frame.Format(0x0c, 2, "SSW (");
+	uint16 ssw = frame.Word(0x0c);
+	sswbuf += ((ssw & M68040::SSW_CP)) ?  "CP" :  "--";
+	sswbuf += ((ssw & M68040::SSW_CU)) ? " CU" : " --";
+	sswbuf += ((ssw & M68040::SSW_CT)) ? " CT" : " --";
+	sswbuf += ((ssw & M68040::SSW_CM)) ? " CM" : " --";
+	sswbuf += ((ssw & M68040::SSW_MA)) ? " MA" : " --";
+	sswbuf += ((ssw & M68040::SSW_ATC)) ? " ATC" : " ---";
+	sswbuf += ((ssw & M68040::SSW_LK)) ? " LK" : " --";
+	sswbuf += ((ssw & M68040::SSW_RW)) ? " RW=R" : " RW=W";
+	sswbuf += string_format(" size=%s", sizestr[(ssw >> 5) & 3]);
+	sswbuf += string_format(" TT=%u", (ssw >> 3) & 3);
+	sswbuf += string_format(" TM=%u", ssw & 7);
+	fprintf(out, "%s)\n", sswbuf.c_str());
+
+	// WB[321]S
+	for (uint i = 0; i < 3; i++) {
+		size_t off = 0x0e + i * 2;
+		std::string wbbuf = frame.Format(off, 2, "");
+		uint16 wbs = frame.Word(off);
+		wbbuf += string_format("WB%u Status (", 3 - i);
+		if ((wbs & 0x80)) {
+			wbbuf += "Valid";
+			wbbuf += string_format(" size=%s", sizestr[(wbs >> 5) & 3]);
+			wbbuf += string_format(" TT=%u", (wbs >> 3) & 3);
+			wbbuf += string_format(" TM=%u", wbs & 7);
+		} else {
+			wbbuf += "no pending";
+		}
+		fprintf(out, "%s)\n", wbbuf.c_str());
+	}
+
+	frame.Print(out, 0x14, 4, "Fault Address");
+	frame.Print(out, 0x18, 4, "WB3 Address");
+	frame.Print(out, 0x1c, 4, "WB3 Data");
+	frame.Print(out, 0x20, 4, "WB2 Address");
+	frame.Print(out, 0x24, 4, "WB2 Data");
+	frame.Print(out, 0x28, 4, "WB1 Address");
+	frame.Print(out, 0x2c, 4, "WB1 Data / PushData 0");
+	frame.Print(out, 0x30, 4, "Push Data 1");
+	frame.Print(out, 0x34, 4, "Push Data 2");
+	frame.Print(out, 0x38, 4, "Push Data 3");
+}
+
+void
+DebuggerMD_m680x0::PrintExceptionFrameB(FILE *out, StackData& frame)
+{
+	frame.ReadWordUntil(46);
+
+	frame.Print(out, 0x08, 2, "");	// internal
+
+	// SSW
+	std::string sswbuf = frame.Format(0x0a, 2, "SSW (");
+	uint16 ssw = frame.Word(0x0a);
+	sswbuf += ((ssw & M68030::SSW_FC)) ?  "FC" :  "--";
+	sswbuf += ((ssw & M68030::SSW_FB)) ? " FB" : " --";
+	sswbuf += ((ssw & M68030::SSW_RC)) ? " RC" : " --";
+	sswbuf += ((ssw & M68030::SSW_RB)) ? " RB" : " --";
+	sswbuf += ((ssw & M68030::SSW_DF)) ? " DF" : " --";
+	sswbuf += ((ssw & M68030::SSW_RM)) ? " RM" : " --";
+	sswbuf += ((ssw & M68030::SSW_RW)) ? " RW=R" : " RW=W";
+	sswbuf += " size=";
+	sswbuf += "LBW3"[(ssw >> 4) & 3];
+	sswbuf += string_format(" FC=%u", ssw & 7);
+	fprintf(out, "%s)\n", sswbuf.c_str());
+
+	frame.Print(out, 0x0c, 2, "Instruction Pipe Stage C");
+	frame.Print(out, 0x0e, 2, "Instruction Pipe Stage B");
+	frame.Print(out, 0x10, 4, "Data Cycle Fault Address");
+	frame.Print(out, 0x14, 4, "");
+	frame.Print(out, 0x18, 4, "Data Output Buffer");
+	frame.Print(out, 0x1c, 4, "");
+	frame.Print(out, 0x20, 4, "");
+	frame.Print(out, 0x24, 4, "Stage B Address");
+	frame.Print(out, 0x28, 4, "");
+	frame.Print(out, 0x2c, 4, "Data Input Buffer");
+
+	// 残りは内部データなのでまとめる。
+	frame.Print(out, 0x30, 4, "(internal registers)");
+	// +$36 にちょっと構造があるけどとりあえず無視。
+	for (uint i = 0x34; i < frame.bytesize(); i += 4) {
+		if (i == 0x34 || i == 0x48) {
+			fprintf(out, "+$%02x:", i);
+		}
+		fprintf(out, " %s", frame.FormatLong(i).c_str());
+		if (i == 0x44) {
+			fprintf(out, "\n");
+		}
+	}
+	fprintf(out, "\n");
+}
