@@ -27,6 +27,10 @@ class DebuggerMD_m88xx0 : public DebuggerMD
 	busaddr TranslateAddr(busaddr laddr) const override;
 
 	uint32 GetPC() const override { return cpu->GetPPC(); }
+	uint32 GetNextPC() override { return GetPC() + 4; }
+	int32 GetAndResetLastVector() override {
+		return cpu->GetAndResetLastVector();
+	}
 
 	void SetStepOut() override;
 	bool IsStepOut() const override;
