@@ -31,11 +31,11 @@ VectorTable::VectorTable(VMType vmtype)
 	 case VMType::NEWS:
 	 case VMType::VIRT68K:
 		InitTableM680x0(vmtype);
-		monitor->func = ToMonitorCallback(&VectorTable::MonitorUpdateM680x0);
+		monitor->SetCallback(&VectorTable::MonitorScreenM680x0);
 		break;
 	 case VMType::LUNA88K:
 		InitTableLuna88k();
-		monitor->func = ToMonitorCallback(&VectorTable::MonitorUpdateM88xx0);
+		monitor->SetCallback(&VectorTable::MonitorScreenM88xx0);
 		// ベクタが(16進数で)3桁必要。
 		w++;
 		break;
@@ -143,7 +143,7 @@ VectorTable::GetExceptionName(int vector) const
 
 // モニタ更新 (M680x0)
 void
-VectorTable::MonitorUpdateM680x0(Monitor *, TextScreen& screen)
+VectorTable::MonitorScreenM680x0(Monitor *, TextScreen& screen)
 {
 // 0         1         2         3         4         5         6         7
 // 012345678901234567890123456789012345678901234567890123456789012345678901234
@@ -179,7 +179,7 @@ VectorTable::MonitorUpdateM680x0(Monitor *, TextScreen& screen)
 
 // モニタ更新 (M88xx0)
 void
-VectorTable::MonitorUpdateM88xx0(Monitor *, TextScreen& screen)
+VectorTable::MonitorScreenM88xx0(Monitor *, TextScreen& screen)
 {
 // 0         1         2         3         4         5         6         7
 // 0123456789012345678901234567890123456789012345678901234567890123456789012346
