@@ -65,6 +65,6 @@ class VectorTable : public Device
 	static std::map<int, const char * const>   name_luna88k;
 };
 
-static inline VectorTable *GetVectorTable() {
+inline VectorTable *GetVectorTable() {
 	return Object::GetObject<VectorTable>(OBJ_VECTOR_TABLE);
 }
