@@ -18,6 +18,40 @@
 <div class="main1">
 <dl>
 
+<dt>1.6.4 (2025/12/08)
+<dd><ul>
+<li>m68k(Fix): 68040 の SRP/URP のマスクを修正。
+これで NetBSD の newpmap カーネルが起動します。
+ <q>Fix SRP/URP register masks in 68040.
+ This makes NetBSD newpmap kernel bootable.</q>
+<li>m68k(Fix): 68030 の SRP/CRP レジスタの下位 4 ビットをクリアしていたのを修正。
+ <q>Fix an issue where the lower 4 bits of SRP/CRP register in 68030 were cleared.</q>
+<li>m68k(Fix): PACK/UNPK 命令のメモリアクセスをワードアクセス1回に修正。
+ <q>Fix memory accesses in PACK/UNPK instructions to a single word access.</q>
+<li>m68k(Update): 68030 の PTEST 命令のコーナーケースをいろいろ実装。
+ <q>Implement several corner cases in 68030 PTEST instruction.</q>
+<li>m68k(Update): 68030 MMU 全体を書き直して若干高速化。
+ <q>Rewrite whole 68030 MMU and improve performance slightly.</q>
+<li>m68k(Update): 68030 ATC を若干高速化。
+ <q>Improve 68030 ATC performance slightly.</q>
+<li>vm(Update): シリアルコンソールエミュレーションに ESC D, ESC M を実装。
+ <q>Implement ESC D and ESC M in serial console emulation.</q>
+<li>host(Fix): usermode ネットワークで不正終了する場合があったのを修正。
+ <q>Fix an abnormal termination in usermode network.</q>
+<li>host(Fix): usermode ネットワークでアプリケーションが終了できないケースがあったのを修正。
+ <q>Fix an issue that the application could not be terminated in usermode
+ network.</q>
+<li>GUI(Update): ページテーブルモニタをいろいろ調整。
+ <q>Improve the page table monitor.</q>
+<li>GUI(Fix): ver 1.6.3 での 68030 ATC モニタの TT ヒット率の表示は誤りだったので削除。
+ <q>Remove incorrect TT hit rate in 68030 ATC monitor since ver 1.6.3.</q>
+<li>debugger(Fix): 異なる例外が同じアドレスで連続して発生した場合に例外履歴に記録されなかったのを修正。
+ <q>Fix an issue where different exceptions occurring consecutively at the
+ same address were not recorded in Exception history.</q>
+<li>debugger(New): pe コマンドを実装。
+ <q>Implement "pe" command.</q>
+</ul><p>
+
 <dt>1.6.3 (2025/11/25)
 <dd><ul>
 <li>m68k(Fix): 68030 テーブルサーチのページアドレスマスクを修正。
@@ -40,9 +74,9 @@
  <q>Show NetBSD/m68k system call number for exception history.</q>
 <li>build(Fix): ver1.6.0 以降 x86_64, i386 以外でビルドエラーになっていたのを修正。
  <q>Fix a build error on platforms other than x86_64 and i386 after ver 1.6.0.</q>
-<li>vm(Update): 注: 次リリース向けの作業中だった時間軸周りの変更が多数入っていますが、動作は変わっていないはずです。
+<li>vm(Update): 注: 将来のリリース向けの作業中だった時間軸周りの変更が多数入っていますが、動作は変わっていないはずです。
 <q>Note: It includes a lot of time axis-related changes that were in the
-work for the next release, but no functional changes are expected.</q>
+work for a future release, but no functional changes are expected.</q>
 </ul><p>
 
 <dt>1.6.2 (2025/11/11)
