@@ -106,8 +106,8 @@ class HD647180ASCIDevice : public Device
 	uint32 PeekRDR(uint n) const;
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
-	void MonitorUpdateChan(TextScreen&, int y, int n) const;
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
+	void MonitorScreenChan(TextScreen&, int y, int n) const;
 
 	void ChangeInterrupt(uint n);
 	void ChangeBaudRate(uint n);
