@@ -931,7 +931,7 @@ MPU64180Device::PeekFRC() const
 		// そこから 10φ ごとに1ずつ減っていく。
 		// そのため、リセット時の時刻を覚えておき、経過時間から計算する。
 		uint64 time = scheduler->GetVirtTime() - timer_epoch;
-		return 0xff - (uint8)(time / (clock_nsec * 10));
+		return 0xff - (uint8)(time / (clock_tsec * 10));
 	}
 }
 
