@@ -12,7 +12,7 @@
 
 // コンストラクタ
 COMDriverNone::COMDriverNone(HostDevice *hostdev_)
-	: inherited(hostdev_, "None")
+	: inherited(hostdev_, "none")
 {
 }
 
