@@ -20,10 +20,14 @@ class COMDriverStdio : public COMDriver
 	explicit COMDriverStdio(HostDevice *hostdev_);
 	~COMDriverStdio() override;
 
-	bool InitDriver() override;
+	bool InitDriver(bool startup) override;
 	int Read() override;
 	void Write(uint32 data) override;
 
  private:
 	struct termios oldtc {};
+	bool tc_changed {};
+
+	// stdio を使えるのは同時に1人だけに限定する。
+	static bool stdio_occupied;
 };
