@@ -463,7 +463,7 @@ COMDriverTCP::GetCommandName(uint8 code)
 
 // モニタ (ドライバ依存情報のみ)
 void
-COMDriverTCP::MonitorUpdateMD(TextScreen& screen, int y)
+COMDriverTCP::MonitorScreenMD(TextScreen& screen, int y)
 {
 	screen.Print(0, y++, "Listen Port: %u", port);
 }
