@@ -24,7 +24,7 @@ class COMDriverTCP : public COMDriver
 	int Dispatch(int udata) override;
 	int Read() override;
 	void Write(uint32 data) override;
-	void MonitorUpdateMD(TextScreen&, int y) override;
+	void MonitorScreenMD(TextScreen&, int y) override;
 
  private:
 	bool Accept();
