@@ -58,7 +58,7 @@ class HostCOMDevice : public HostDevice
 	int Read() override;
 	void Write() override;
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// キュー
 	COMQueue txq {};
