@@ -15,13 +15,9 @@
 #include "netdriver.h"
 #include "spscqueue.h"
 
-// パケット
-class NetPacket : public std::array<uint8, 1600>
+// パケット。
+class NetPacket
 {
-	// ジャンボフレームでないイーサネットフレームは最大 1518バイトだが
-	// このパケットバッファの長さは 1519 バイト以上必要。
-	// vm/lance が 1518 バイトを越えたことを検出するのに使っている。
-
  public:
 	NetPacket() {
 		Clear();
@@ -29,33 +25,57 @@ class NetPacket : public std::array<uint8, 1600>
 
 	// バッファをクリアする
 	void Clear() {
-		length = 0;
-		Seek(0);
+		buf.clear();
+		readpos = 0;
+	}
+
+	// バッファサイズ (パケット長) を変更する。
+	void Resize(uint newlength) {
+		buf.resize(newlength);
 	}
 
 	// パケットに1バイト追加する
-	void Append(uint8 data) { (*this)[length++] = data; }
+	void Append(uint8 data) {
+		buf.push_back(data);
+	}
 
 	// 読み出し開始位置を設定
-	void Seek(int offset_) { offset = offset_; }
+	void Seek(size_t readpos_) { readpos = readpos_; }
+
+	// バッファの先頭を返す。
+	uint8 *Data() { return buf.data(); }
+	const uint8 *Data() const { return buf.data(); }
+
+	// パケットサイズを取得
+	uint Length() const { return (uint)buf.size(); }
 
 	// 読み出しの残りバイト数を返す
-	int GetRemain() const { return length - offset; }
+	uint GetRemain() const { return Length() - readpos; }
 
 	// 1バイト読み出す。EOP なら -1 を返す
 	uint32 Read() {
-		if (offset < length) {
-			return (*this)[offset++];
+		if (readpos < Length()) {
+			return buf[readpos++];
 		} else {
 			return (uint32)-1;
 		}
 	}
 
-	// バッファ内の有効長
-	uint length {};
+	// ポインタを進めず指定の位置のデータを読み出す。
+	// pos が不正なら -1 を返す。
+	uint32 Peek(uint pos) const {
+		if (pos < Length()) {
+			return buf[pos];
+		} else {
+			return (uint32)-1;
+		}
+	}
+
+ private:
+	std::vector<uint8> buf {};
 
 	// 現在の読み出し位置
-	int offset {};
+	uint readpos {};
 };
 
 // MAC アドレスフィルタ。
