@@ -46,7 +46,10 @@ class Logger : public Object, public ThreadBase
 	void TerminateThread();
 
 	// 標準出力にも出すかどうか
-	void UseStdout(bool val) { use_stdout = val; }
+	void UseStdout(bool val);
+
+	// 標準出力への出力をシリアライズするかどうか。(デバッガから使う)
+	void SetSerialize(bool val);
 
 	// ログの表示桁数を変更する。
 	bool ResizeCol(int);
@@ -60,6 +63,7 @@ class Logger : public Object, public ThreadBase
 	Monitor *GetMonitor() const { return monitor; }
 
  private:
+	void ReconfigStdout();
 	void OnStart();
 	void Terminate();
 	void ThreadRun();
@@ -77,8 +81,12 @@ class Logger : public Object, public ThreadBase
 	std::mutex queue_mtx {};
 	std::condition_variable cv {};
 
-	// 標準出力にも出すかどうか
+	// 標準出力にも出すかどうかと、シリアライズするかどうか。
 	bool use_stdout {};
+	bool do_serialize {};
+	// その結果のどこで出力するか。
+	bool stdout_sender {};		// 呼び出し元スレッドで出力
+	bool stdout_logger {};		// ログスレッドで出力
 
 	// バックログの実体。
 	std::deque<std::string> logs {};
