@@ -25,7 +25,7 @@ class NetDriverBPF : public NetDriver
 	int Read(NetPacket *p) override;
 	void Write(const void *buf, int buflen) override;
 
-	void MonitorUpdateMD(TextScreen&, int y) override;
+	void MonitorScreenMD(TextScreen&, int y) override;
 
  private:
 	void Close();
