@@ -194,25 +194,56 @@ NetDriverSlirp::Write(const void *buf, int buflen)
 int
 NetDriverSlirp::Read(NetPacket *p)
 {
-	ssize_t n;
-	uint32 len;
+	ssize_t r;
+	ssize_t len;
+	ssize_t bufsize;
+	uint8 *buf;
+	uint32 datalen;
 
 	// 先頭4バイトに後続パケット長を入れてある。
-	len = 0;
-	n = read(rxd, &len, sizeof(len));
-	if (n < 0) {
-		putmsg(0, "read(len) failed: %s", strerror(errno));
-		return NODATA;
+	buf = reinterpret_cast<uint8 *>(&datalen);
+	bufsize = sizeof(datalen);
+	for (len = 0; len < bufsize; ) {
+		r = read(rxd, buf + len, bufsize - len);
+		if (r < 0) {
+			putmsg(0, "read(len) failed: %s", strerror(errno));
+			goto nodata;
+		}
+		if (r == 0) {
+			putmsg(0, "read(len) failed: EOF?");
+			goto nodata;
+		}
+		len += r;
 	}
 
-	n = read(rxd, p->data(), len);
-	if (n < 0) {
-		putmsg(0, "read(buf) failed: %s", strerror(errno));
-		return NODATA;
+	// データ本体。
+	p->Resize(datalen);
+	buf = p->Data();
+	for (len = 0; len < datalen; ) {
+		r = read(rxd, buf + len, datalen - len);
+		if (r < 0) {
+			putmsg(0, "read(data) failed: %s", strerror(errno));
+			goto nodata;
+		}
+		if (r == 0) {
+			putmsg(0, "read(data) failed: EOF?");
+			goto nodata;
+		}
+		len += r;
 	}
 
-	p->length = n;
 	return 0;
+
+ nodata:
+	// 一旦全部読み捨てるくらいしか。
+	std::vector<uint8> dropbuf(1024);
+	for (;;) {
+		r = read(rxd, dropbuf.data(), dropbuf.size());
+		if (r <= 0) {
+			break;
+		}
+	}
+	return NODATA;
 }
 
 // usermode を使えるのは同時に1人だけに限定する。
@@ -758,6 +789,9 @@ void
 SlirpThread::Terminate()
 {
 	txd_r.Close();
+	txd_w.Close();
+	rxd_r.Close();
+	rxd_w.Close();
 }
 
 // スレッド
