@@ -43,7 +43,7 @@ class NetDriverSlirp : public NetDriver
 	int Read(NetPacket *p) override;
 	void Write(const void *buf, int buflen) override;
 
-	void MonitorUpdateMD(TextScreen&, int y) override;
+	void MonitorScreenMD(TextScreen&, int y) override;
 
 	// Slirp ドライバが稼働中かどうか (高々1つなのでグローバル)
 	static bool IsOccupied() noexcept { return slirp_occupied; }
@@ -80,7 +80,7 @@ class SlirpThread : public ThreadDevice
 	void Close();
 	void Terminate() override;
 
-	void MonitorUpdate(Monitor *, TextScreen&);
+	void MonitorScreen(Monitor *, TextScreen&);
 
 	// コールバック (C のコールバックから呼ばれるので public)
 	int AddPollCB(int fd, int slevents);
