@@ -23,7 +23,7 @@ class NetDriverTap : public NetDriver
 	int Read(NetPacket *p) override;
 	void Write(const void *buf, int buflen) override;
 
-	void MonitorUpdateMD(TextScreen&, int y) override;
+	void MonitorScreenMD(TextScreen&, int y) override;
 
  private:
 #if defined(__linux__)
