@@ -39,6 +39,6 @@ class SignalThread : public ThreadDevice
 	volatile bool request_terminate {};
 };
 
-static inline SignalThread *GetSignalThread() {
+inline SignalThread *GetSignalThread() {
 	return Object::GetObject<SignalThread>(OBJ_SIGNAL_THREAD);
 }
