@@ -24,7 +24,7 @@ class SoundDriverNetBSD : public SoundDriver
 
 	void Write(const int16 *) override;
 
-	void MonitorUpdateMD(TextScreen&, int y) override;
+	void MonitorScreenMD(TextScreen&, int y) override;
 
  private:
 	autofd fd {};
