@@ -111,6 +111,10 @@ class FixedQueue final : private std::vector<T>
 		// XXX 範囲チェックすべきだがとりあえず
 		return (*this)[(start + idx) % capacity];
 	}
+	// 最新の要素を覗き見る。
+	T PeekLatest() const {
+		return Peek(Length() - 1);
+	}
 
 	// 要素数を返す
 	constexpr uint Capacity() const {
