@@ -25,12 +25,12 @@
 using kevent_udata_t = decltype(kevent::udata);
 
 // udata と int の相互変換
-static inline kevent_udata_t
+inline kevent_udata_t
 EV_INT2UDATA(int x)
 {
 	return (kevent_udata_t)(intptr_t)x;
 }
-static inline int
+inline int
 EV_UDATA2INT(kevent_udata_t x)
 {
 	return (int)(intptr_t)x;
@@ -39,7 +39,7 @@ EV_UDATA2INT(kevent_udata_t x)
 #define kevent_set(k, e, n)		kevent((k), (e), (n), NULL, 0, NULL)
 #define kevent_poll(k, e, n, t)	kevent((k), NULL, 0, (e), (n), (t))
 
-static inline int
+inline int
 kevent_add(int kq, int fd, int filter, int action, int udata)
 {
 	struct kevent kev;
