@@ -12,7 +12,6 @@
 
 #include "geometric.h"
 #include "mainapp.h"
-#include "object.h"
 #include "textscreen.h"
 #include <array>
 
@@ -25,45 +24,34 @@ enum {
 };
 
 // 識別子 (n番目で指定)
-static constexpr uint ID_MONITOR_ATC(uint n) {
-	return ID_MONITOR_ATC0 + n;
-}
-static constexpr uint ID_MONITOR_CMMU(uint n) {
-	return ID_MONITOR_CMMU0 + n;
-}
-static constexpr uint ID_MONITOR_HOSTCOM(uint n) {
-	return ID_MONITOR_HOSTCOM0 + n;
-}
-static constexpr uint ID_MONITOR_HOSTNET(uint n) {
-	return ID_MONITOR_HOSTNET0 + n;
-}
-static constexpr uint ID_SUBWIN_CACHE(uint n) {
-	return ID_SUBWIN_CACHE0 + n;
-}
-static constexpr uint ID_MONITOR_MEMDUMP(uint n) {
-	return ID_MONITOR_MEMDUMP0 + n;
-}
-static constexpr uint ID_MONITOR_RTL8019AS(uint n) {
+constexpr uint ID_MONITOR_ATC(uint n)		{ return ID_MONITOR_ATC0 + n; }
+constexpr uint ID_MONITOR_CMMU(uint n)		{ return ID_MONITOR_CMMU0 + n; }
+constexpr uint ID_MONITOR_HOSTCOM(uint n)	{ return ID_MONITOR_HOSTCOM0 + n; }
+constexpr uint ID_MONITOR_HOSTNET(uint n)	{ return ID_MONITOR_HOSTNET0 + n; }
+constexpr uint ID_SUBWIN_CACHE(uint n)		{ return ID_SUBWIN_CACHE0 + n; }
+constexpr uint ID_MONITOR_MEMDUMP(uint n)	{ return ID_MONITOR_MEMDUMP0 + n; }
+constexpr uint ID_MONITOR_RTL8019AS(uint n) {
 	return ID_MONITOR_RTL8019AS0 + n;
 }
-static constexpr uint ID_MONITOR_VIRTIO_BLOCK(uint n) {
+constexpr uint ID_MONITOR_VIRTIO_BLOCK(uint n) {
 	return ID_MONITOR_VIRTIO_BLOCK0 + n;
 }
-static constexpr uint ID_MONITOR_XPMEMDUMP(uint n) {
+constexpr uint ID_MONITOR_XPMEMDUMP(uint n) {
 	return ID_MONITOR_XPMEMDUMP0 + n;
 }
 // 判定
-static constexpr bool IS_MONITOR_MEMDUMP(uint id) {
+constexpr bool IS_MONITOR_MEMDUMP(uint id) {
 	return (ID_MONITOR_MEMDUMP0 <= id &&
 	        id < ID_MONITOR_MEMDUMP(MAX_MEMDUMP_MONITOR));
 }
-static constexpr bool IS_MONITOR_XPMEMDUMP(uint id) {
+constexpr bool IS_MONITOR_XPMEMDUMP(uint id) {
 	return (ID_MONITOR_XPMEMDUMP0 <= id &&
 	        id < ID_MONITOR_XPMEMDUMP(MAX_XPMEMDUMP_MONITOR));
 }
 
 class BitmapRGBX;
 class Monitor;
+class Object;
 using MonitorScreenCallback_t = void (Object::*)(Monitor *, TextScreen&);
 using MonitorBitmapCallback_t = void (Object::*)(Monitor *, BitmapRGBX&);
 
@@ -73,7 +61,7 @@ class Monitor
  public:
 	Monitor();
 	Monitor(uint id_, Object *obj_);
-	~Monitor();
+	virtual ~Monitor();
 
 	uint GetId() const { return id; }
 
@@ -186,6 +174,7 @@ class MonitorManager
 	// Create() の後、Init() より前に -M オプションの処理があるため。
 	// see wx/wxapp.cpp
 	Monitor *Regist(uint id_, Object *parent_);
+	Monitor *Regist(Monitor *monitor_);
 
 	// 削除
 	void Unregist(Monitor *mon_);
@@ -223,6 +212,9 @@ class MonitorManager
 	void Fix();
 
  private:
+	// Regist() の実体。
+	Monitor *RegistCommon(uint id_, Object *parent_, Monitor *monitor_);
+
 	// モニターインスタンスの配列。添字はモニター ID なので歯抜け。
 	std::array<std::unique_ptr<Monitor>, ID_SUBWIN_MAX> monitors /*{}*/;
 
