@@ -17,7 +17,7 @@
 #include <chrono>
 
 // ホストの現在の UNIX 時刻を [usec] 単位で取得する。
-static inline uint64
+inline uint64
 get_hosttime_usec()
 {
 	using namespace std::chrono;
@@ -27,7 +27,7 @@ get_hosttime_usec()
 }
 
 // ホストの現在の UNIX 時刻を [sec] 単位で取得する。
-static inline uint64
+inline uint64
 get_hosttime_sec()
 {
 	using namespace std::chrono;
