@@ -20,18 +20,18 @@ class Monitor;
 class TextScreen;
 
 // オブジェクト ID
-static constexpr uint OBJ_BANKRAM(uint n) { return OBJ_BANKRAM0 + n; }
-static constexpr uint OBJ_DMAC_CH(uint n) { return OBJ_DMAC_CH0 + n; }
-static constexpr uint OBJ_ETHERNET(uint n) { return OBJ_ETHERNET0 + n; }
-static constexpr uint OBJ_FDD(uint n) { return OBJ_FDD0 + n; }
-static constexpr uint OBJ_GFPIC(uint n) { return OBJ_GFPIC0 + n; }
-static constexpr uint OBJ_HOSTCOM(uint n) { return OBJ_HOSTCOM0 + n; }
-static constexpr uint OBJ_HOSTNET(uint n) { return OBJ_HOSTNET0 + n; }
-static constexpr uint OBJ_M88200(uint n) { return OBJ_M88200_0 + n; }
-static constexpr uint OBJ_MPU_MEMDUMP(uint n) { return OBJ_MPU_MEMDUMP0 + n; }
-static constexpr uint OBJ_NEREID_BOARD(uint n) { return OBJ_NEREID_BOARD0 + n; }
-static constexpr uint OBJ_VIRTIO_BLOCK(uint n) { return OBJ_VIRTIO_BLOCK0 + n; }
-static constexpr uint OBJ_XP_MEMDUMP(uint n) { return OBJ_XP_MEMDUMP0 + n; }
+constexpr uint OBJ_BANKRAM(uint n)		{ return OBJ_BANKRAM0 + n; }
+constexpr uint OBJ_DMAC_CH(uint n)		{ return OBJ_DMAC_CH0 + n; }
+constexpr uint OBJ_ETHERNET(uint n)		{ return OBJ_ETHERNET0 + n; }
+constexpr uint OBJ_FDD(uint n)			{ return OBJ_FDD0 + n; }
+constexpr uint OBJ_GFPIC(uint n)		{ return OBJ_GFPIC0 + n; }
+constexpr uint OBJ_HOSTCOM(uint n)		{ return OBJ_HOSTCOM0 + n; }
+constexpr uint OBJ_HOSTNET(uint n)		{ return OBJ_HOSTNET0 + n; }
+constexpr uint OBJ_M88200(uint n)		{ return OBJ_M88200_0 + n; }
+constexpr uint OBJ_MPU_MEMDUMP(uint n)	{ return OBJ_MPU_MEMDUMP0 + n; }
+constexpr uint OBJ_NEREID_BOARD(uint n)	{ return OBJ_NEREID_BOARD0 + n; }
+constexpr uint OBJ_VIRTIO_BLOCK(uint n)	{ return OBJ_VIRTIO_BLOCK0 + n; }
+constexpr uint OBJ_XP_MEMDUMP(uint n)	{ return OBJ_XP_MEMDUMP0 + n; }
 
 // ログ表示に指定するラムダ式の便利マクロ。
 // fmt 内では __func__ が使えないので代わりに lam_func を使うこと。
