@@ -150,6 +150,9 @@ MPU68030Device::read_nocache(busaddr addr)
 	// MPU(68030) は、A1-A0、残りバイト数、デバイスの応答サイズの情報から
 	// 受け取ったデータバスのうち適切なところを切り出して使う。
 
+	putlog(3, "read_nocache %u.%08x sz=%c",
+		addr.GetFC(), addr.Addr(), "0BW3L"[addr.GetSize()]);
+
 	uint32 data = 0;
 	for (;;) {
 		bus.laddr = addr;
@@ -205,7 +208,7 @@ OPERMASK(uint32 offset, uint32 size)
 busdata
 MPU68030Device::read_cache(m68030Cache *cache, busaddr addr)
 {
-	putlog(2, "read_cache $%u.%08x.%c",
+	putlog(3, "read_cache %u.%08x sz=%c",
 		addr.GetFC(), addr.Addr(), "0BW3L"[addr.GetSize()]);
 
 	uint32 data = 0;
@@ -226,7 +229,7 @@ MPU68030Device::read_cache(m68030Cache *cache, busaddr addr)
 		if (__predict_true(l->tag == tag && l->valid[sel])) {
 			cache->stat_hit++;
 			entry_data = l->data[sel];
-			putlog(2, " entry_data=$%08x (match)", entry_data);
+			putlog(3, " entry_data=$%08x (match)", entry_data);
 		} else {
 			cache->stat_miss++;
 
@@ -234,10 +237,10 @@ MPU68030Device::read_cache(m68030Cache *cache, busaddr addr)
 			bus.laddr = addr;
 			bus.paddr = addr;
 			if (__predict_false(TranslateRead() == false)) {
-				putlog(2, " TranslateRead BusErr");
+				putlog(3, " TranslateRead BusErr");
 				return BusData::BusErr;
 			}
-			putlog(2, " paddr=$%08x.%c",
+			putlog(3, " paddr=$%08x.%c",
 				bus.paddr.Addr(), "0BW3L"[bus.paddr.GetSize()]);
 
 			busdata bd;
@@ -255,7 +258,7 @@ MPU68030Device::read_cache(m68030Cache *cache, busaddr addr)
 						l->tag = tag;
 						l->valid_all = -1;
 						entry_data = l->data[sel];
-						putlog(2, " entry_data=$%08x (burst)", entry_data);
+						putlog(3, " entry_data=$%08x (burst)", entry_data);
 					} else {
 						// シングル充填を4回。
 						uint32 opermask = OPERMASK(reqoffset, opersize);
@@ -264,7 +267,7 @@ MPU68030Device::read_cache(m68030Cache *cache, busaddr addr)
 							return bd;
 						}
 						entry_data = bd.Data();
-						putlog(2, " entry_data=$%08x (line)", entry_data);
+						putlog(3, " entry_data=$%08x (line)", entry_data);
 					}
 				} else {
 					// このエントリだけ充填。
@@ -311,11 +314,11 @@ MPU68030Device::read_cache(m68030Cache *cache, busaddr addr)
 			// 要求サイズがこのエントリをはみ出していない。
 			entry_data >>= (4 - reqoffset - opersize) * 8;
 			data |= entry_data & mask;
-			putlog(2, " data=$%0*x (done)", opersize * 2, data);
+			putlog(3, " data=$%0*x (done)", opersize * 2, data);
 			break;
 		} else {
 			data |= entry_data & mask;
-			putlog(2, " data=$%0*x", opersize * 2, data);
+			putlog(3, " data=$%0*x", opersize * 2, data);
 		}
 		addr += opersize;
 		addr.ChangeSize(reqsize - opersize);
@@ -486,8 +489,9 @@ MPU68030Device::write_bus(busaddr addr, uint32 data)
 {
 	m68030Cache *cache = dcache.get();
 
-	putlog(2, "write_bus %u.%08x sz=%u data=$%0*x",
-		addr.GetFC(), addr.Addr(), addr.GetSize(), addr.GetSize() * 2, data);
+	putlog(3, "write_bus %u.%08x sz=%c data=$%0*x",
+		addr.GetFC(), addr.Addr(), "0BW3L"[addr.GetSize()],
+		addr.GetSize() * 2, data);
 	for (;;) {
 		uint32 nextdata;
 		uint32 reqoffset = addr.Addr() & 3;
@@ -516,11 +520,11 @@ MPU68030Device::write_bus(busaddr addr, uint32 data)
 			for (;;) {
 				bd = write_phys(outdata);
 				if (__predict_false(bd.IsBusErr())) {
-					putlog(2, " write_phys -> BusErr");
+					putlog(3, " write_phys -> BusErr");
 					break;
 				}
 				uint32 breqsize = bus.paddr.GetSize();
-				putlog(2, " write_phys $%08x data=$%0*x",
+				putlog(3, " write_phys $%08x data=$%0*x",
 					bus.paddr.Addr(), breqsize * 2, outdata);
 				uint32 portsize = bd.GetSize();
 				uint32 offset = bus.paddr.Addr() & (portsize - 1);
@@ -600,7 +604,7 @@ MPU68030Device::write_bus(busaddr addr, uint32 data)
 		if (nextsize == 0) {
 			break;
 		}
-		putlog(2, " nextsize=%u", nextsize);
+		putlog(3, " nextsize=%u", nextsize);
 		addr += addr.GetSize();
 		addr.ChangeSize(nextsize);
 		data = nextdata;
