@@ -13,7 +13,7 @@
 bool
 MPU68040Device::TranslateRead()
 {
-	m68040TT *tt;
+	const m68040TT *tt;
 	m68040ATC *atc;
 
 	putlog(3, "TranslateRead  %c.$%08x",
@@ -22,10 +22,10 @@ MPU68040Device::TranslateRead()
 	// まず TT をチェック。
 	if (bus.laddr.IsData()) {
 		atc = atc_data.get();
-		tt = CheckTT(mmu_dtt);
+		tt = TTMatch(mmu_dtt);
 	} else {
 		atc = atc_inst.get();
-		tt = CheckTT(mmu_itt);
+		tt = TTMatch(mmu_itt);
 	}
 	if (tt != NULL) {
 		putlog(3, "TranslateRead  %s matched", tt->GetName());
@@ -49,7 +49,7 @@ MPU68040Device::TranslateWrite()
 		(bus.laddr.IsSuper() ? 'S' : 'U'), bus.laddr.Addr());
 
 	// まず TT をチェック。
-	m68040TT *tt = CheckTT(mmu_dtt);
+	const m68040TT *tt = TTMatch(mmu_dtt);
 	if (tt) {
 		if (tt->w) {
 			putlog(3, "TranslateWrite %s matched (WriteProtected)",
@@ -74,7 +74,7 @@ MPU68040Device::TranslateWrite()
 // *TTn にマッチすれば、マッチした方のポインタを返す。
 // マッチしなければ NULL を返す。
 m68040TT *
-MPU68040Device::CheckTT(std::array<std::unique_ptr<m68040TT>, 2>& ttbase) const
+MPU68040Device::TTMatch(std::array<std::unique_ptr<m68040TT>, 2>& ttbase) const
 {
 	for (int n = 0; n < 2; n++) {
 		m68040TT *tt = ttbase[n].get();
@@ -373,9 +373,9 @@ MPU68040Device::TranslatePeek(busaddr laddr)
 
 	// TT を自前でサーチ。
 	if (laddr.IsData()) {
-		tt = CheckTT(mmu_dtt);
+		tt = TTMatch(mmu_dtt);
 	} else {
-		tt = CheckTT(mmu_itt);
+		tt = TTMatch(mmu_itt);
 	}
 	if (__predict_false(tt != NULL)) {
 		if (tt->Match(laddr)) {
@@ -671,25 +671,29 @@ MPU68040Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 	// IDX TagAddr     PAddr     Stat IDX TagAddr     PAddr     Stat
 	// [0] S.12345'000 12345'000 ---- [1] S.12345'000 12345'000 ----
 
+	bool enable = mmu_tc->e;
+	TA attr_e = enable ? TA::Normal : TA::Disable;
+
 	screen.Clear();
-	screen.Puts(0, 0, "<Data ATC>");
-	screen.Puts(x, 0, "<Instruction ATC>");
+	screen.Puts(0, 0, attr_e, "<Data ATC>");
+	screen.Puts(x, 0, attr_e, "<Instruction ATC>");
 	for (int i = 0; i < 4; i++) {
 		screen.Puts(i * 31 + (i & 2), 1, "IDX TagAddr     PAddr     Stat");
 	}
-	MonitorScreenATC1(screen, 0, atc_data.get());
-	MonitorScreenATC1(screen, x, atc_inst.get());
+	MonitorScreenATC1(screen, 0, enable, atc_data.get());
+	MonitorScreenATC1(screen, x, enable, atc_inst.get());
 }
 
 void
-MPU68040Device::MonitorScreenATC1(TextScreen& screen, int x,
+MPU68040Device::MonitorScreenATC1(TextScreen& screen, int x, bool enable,
 	const m68040ATC *atc)
 {
 	int y = 2;
+	TA attr_e = enable ? TA::Normal : TA::Disable;
 
 	for (uint i = 0; i < atc->sets.size(); i++) {
 		const m68040ATCSet& set = atc->sets[i];
-		screen.Print(x, y, "[%x]", i);
+		screen.Print(x, y, attr_e, "[%x]", i);
 
 		// 古い順に取り出して 3-0 の順序をつける。(新しい順に表示するため)
 		int order[4];
