@@ -52,10 +52,10 @@ struct m680x0FPUType
 	bool Is4060FPU() const noexcept	{ return (type & M680x0) != 0; }
 	bool Is6888x() const noexcept	{ return (type & M6888x) != 0; }
 };
-static inline bool operator==(const m680x0FPUType& a, const m680x0FPUType& b) {
+inline bool operator==(const m680x0FPUType& a, const m680x0FPUType& b) {
 	return (a.type == b.type);
 }
-static inline bool operator!=(const m680x0FPUType& a, const m680x0FPUType& b) {
+inline bool operator!=(const m680x0FPUType& a, const m680x0FPUType& b) {
 	return !(a == b);
 }
 
