@@ -307,7 +307,7 @@ MPU680x0Device::GenerateExframe7(uint vector, uint16 sr)
 	//   +$30.L   PUSH DATA LW1 (PD1)
 	//   +$34.L   PUSH DATA LW2 (PD2)
 	//   +$38.L   PUSH DATA LW3 (PD3)
-	//   +$40
+	//   +$3c
 	//	こっちから上に向かって PUSH
 
 	// SSW
@@ -352,7 +352,7 @@ MPU680x0Device::GenerateExframe7(uint vector, uint16 sr)
 	push_2(0);		// WB3S
 	push_2(ssw);
 	push_4(ea);
-	push_2(0x7000 | vector);
+	push_2(0x7000 | (vector << 2));
 	push_4(pc);
 	push_2(sr);
 }
