@@ -4147,8 +4147,8 @@ m680x0disasm::ops_pmove(Reg reg, m680x0disasm::Size sz)
 	}
 }
 
-// %1111_000nnn_nnnnnn .......... -3-	MMU_OP
-OP_DEF(mmuop)
+// %1111_000nnn_nnnnnn .......... -3-	MMU30_OP
+OP_DEF(mmu30)
 {
 	uint16 ext = fetch2();
 	switch (ext >> 8) {
