@@ -2014,6 +2014,7 @@ MPU680x0Device::fpu_op_frestore()
 	uint32 ea;
 	uint32 fmtword;
 	uint32 ver_len;
+	uint32 ver;
 	uint32 len;
 	bool postinc;
 
@@ -2085,15 +2086,17 @@ MPU680x0Device::fpu_op_frestore()
 	ea += 4;
 
 	ver_len = fmtword >> 16;
+	ver = ver_len >> 8;
 	len = ver_len & 0xff;
 
 	if (GetFPUType().Is4060FPU()) {
-		if (ver_len == 0) {
+		if (ver == 0) {
 			// NULL フレーム。
 
 			// NULL フレームのリストアは FPU の状態をリセットする。
 			CYCLE3(frestore_null);
 			ResetFPU(false);
+			goto done;
 		} else if (ver_len == 0x4100) {
 			// IDLE フレーム。
 
@@ -2119,12 +2122,14 @@ MPU680x0Device::fpu_op_frestore()
 			goto done;
 		}
 	} else /* 68881 */ {
-		if (ver_len == 0) {
+		if (ver == 0) {
 			// NULL フレーム。
+			// 長さフィールドは見ない。(MC68881UM.pdf 6.4.2.1)
 
 			// NULL フレームのリストアは FPU の状態をリセットする。
 			CYCLE3(frestore_null);
 			ResetFPU(false);
+			goto done;
 		} else if (ver_len == 0x1f18) {
 			// IDLE フレーム。
 
@@ -2286,7 +2291,7 @@ MPU68040Device::GetFPUTagName(int32 tag)
 
 // モニター更新 (040 内部情報)
 void
-MPU68040Device::MonitorUpdateFPU40(TextScreen& screen, int y, const FPU40& tmp)
+MPU68040Device::MonitorScreenFPU40(TextScreen& screen, int y, const FPU40& tmp)
 {
 	// CMDREG1B:$xxxx OPCLASS=0 Rs=7 Rd=7 cmd=00(FTWOTOX) Flags: E3 E1 T
 	// ETEMP :$01234567_01234567_01234567   STAG:1(Unnormal)
