@@ -1545,8 +1545,8 @@
 	 case (0xf140 >> 6):
 	 case (0xf180 >> 6):
 	 case (0xf1c0 >> 6):
-		// %1111_000nnn_nnnnnn	MMU_OP
-		OP_FUNC(mmuop);
+		// %1111_000nnn_nnnnnn	MMU30_OP
+		OP_FUNC(mmu30);
 		break;
 	 case (0xf200 >> 6):
 		// %1111_001000_nnnnnn	FPGEN
