@@ -88,8 +88,8 @@ class EA {
 		val = 0;
 		size = 0;
 	}
-	int type() const { return (mode >> 3) & 7; };
-	int num()  const { return (mode & 7); };
+	int type() const { return (mode >> 3) & 7; }
+	int num()  const { return (mode & 7); }
 };
 
 /* 参照種別 */
