@@ -42,7 +42,7 @@ BankRAMDevice::Init()
 		return false;
 	}
 
-	wait = busdata::Wait(1 * mpu->GetClock_nsec());
+	wait = busdata::Wait(1 * mpu->GetClock_tsec());
 
 	return true;
 }
