@@ -24,6 +24,6 @@ class BusErrDevice : public IODevice
 	busdata Peek1(uint32 addr) override;
 };
 
-static inline BusErrDevice *GetBusErrDevice() {
+inline BusErrDevice *GetBusErrDevice() {
 	return Object::GetObject<BusErrDevice>(OBJ_BUSERR);
 }
