@@ -370,9 +370,12 @@ ConsoleDevice::PutcharESC(uint32 ch)
 		Locate(0, 0);
 		break;
 
-	 case 'M':		// 1行上に移動 (画面を1行下にスクロール)
+	 case 'D':		// 画面を1行上にスクロール (カーソル位置は変わらない)
+		ScrollUp();
+		break;
+
+	 case 'M':		// 画面を1行下にスクロール (カーソル位置は変わらない)
 		ScrollDown();
-		Locate(0, 0);
 		break;
 
 	 case '*':		// G2
