@@ -181,6 +181,6 @@ class ConsoleKeyboard : public DumbKeyboard
 	COMDriverConsole *comdriver {};
 };
 
-static inline ConsoleDevice *GetConsoleDevice() {
+inline ConsoleDevice *GetConsoleDevice() {
 	return Object::GetObject<ConsoleDevice>(OBJ_CONSOLE);
 }
