@@ -1136,7 +1136,7 @@ DMACDevice::StartTransfer(DMACChan *chan)
 	 case DMAC::CHAIN_reserved:
 		// とりあえず DISABLED と同じ動作にしておくか。
 		chan_putlog(chan, 1, "Undefined CHAIN=1 (ignored)");
-		// FALLTHROUGH
+		FALLTHROUGH;
 	 case DMAC::CHAIN_DISABLED:
 		chan_putlog(chan, 1, "%s", MakeStartLog(chan).c_str());
 		break;
@@ -1752,6 +1752,7 @@ DMACDevice::TransferLog(DMACChan *chan, uint op, busaddr addr,
 		if (r.IsOK()) {
 			str += string_format("$%04x", r.Data());
 		}
+		break;
 	 case WR_M8:
 	 case WR_D8:
 		str += string_format("$%02x", (uint32)data);
