@@ -44,6 +44,6 @@ class ExtRAMDevice : public IODevice
 	uint ram_size {};
 };
 
-static inline ExtRAMDevice *GetExtRAMDevice() {
+inline ExtRAMDevice *GetExtRAMDevice() {
 	return Object::GetObject<ExtRAMDevice>(OBJ_EXTRAM);
 }
