@@ -55,6 +55,6 @@ class GFPICDevice : public InterruptDevice
 	InterruptDevice *interrupt {};
 };
 
-static inline GFPICDevice *GetGFPICDevice(int id_) {
+inline GFPICDevice *GetGFPICDevice(int id_) {
 	return Object::GetObject<GFPICDevice>(OBJ_GFPIC(id_));
 }
