@@ -79,6 +79,6 @@ class GFRTCDevice : public RTCDevice
 	uint min;
 	uint sec;
 
-	// TIME レジスタラッチ
-	uint64 time_nsec {};
+	// TIME レジスタラッチ。Goldfish 仕様により 1[nsec] 単位。
+	union64 time_nsec {};
 };
