@@ -78,6 +78,6 @@ class GFTTYDevice : public IODevice
 	MainbusDevice *mainbus {};
 };
 
-static inline GFTTYDevice *GetGFTTYDevice() {
+inline GFTTYDevice *GetGFTTYDevice() {
 	return Object::GetObject<GFTTYDevice>(OBJ_GFTTY);
 }
