@@ -436,6 +436,25 @@ Human68kDevice::FLineOp()
 		IOCS();
 		break;
 
+	 case 0xfe11:		// FPACK __LTOS
+	 {
+		putlog(1, "FPACK __LTOS");
+		uint32 data = RegD(0);
+		uint32 dst = RegA(0);
+		char buf[16];
+		snprintf(buf, sizeof(buf), "%d", data);
+		for (char *p = buf; ; p++, dst++) {
+			uint8 c = *p;
+			mainbus->HVWrite1(dst, c);
+			if (c == 0) {
+				break;
+			}
+		}
+		// '\0' の位置を A0 に返す。
+		RegA(0) = dst;
+		break;
+	 }
+
 	 case 0xff00:		// _EXIT
 		putlog(1, "DOS _EXIT");
 		// XXX CPU の実行を止める。方式自体を I/O 方式に見直したときには
