@@ -157,7 +157,7 @@ class Keyboard : public DumbKeyboard
 };
 
 // フルキーボードの取得 (シリアルキーボードは含まない)
-static inline Keyboard *GetKeyboard() {
+inline Keyboard *GetKeyboard() {
 	return Object::GetObject<Keyboard>(OBJ_KEYBOARD);
 }
 
