@@ -130,6 +130,6 @@ class LunafbDevice : public PlaneVRAMDevice
 	Monitor *monitor {};
 };
 
-static inline LunafbDevice *GetLunafbDevice() {
+inline LunafbDevice *GetLunafbDevice() {
 	return Object::GetObject<LunafbDevice>(OBJ_PLANEVRAM);
 }
