@@ -178,11 +178,11 @@ class MPSCCChan final
 
 	// LUNA の場合は TxC, RxC ピンに供給されているクロック。
 	// X68030 の場合は Z8530 内部で生成されている基準クロック。
-	// 誤差を減らすため 12 ビット分の時間 [nsec] としている。
-	uint64 xc12_ns {};
+	// 誤差を減らすため 12 ビット分の時間 [tsec] としている。
+	uint64 xc12_tsec {};
 
-	// 実際の 12 ビットの通信にかかる時間。xc12_ns に倍率をかけたもの。
-	uint64 bit12_ns {};
+	// 実際の 12 ビットの通信にかかる時間。xc12_tsec に倍率をかけたもの。
+	uint64 bit12_tsec {};
 };
 
 class MPSCC
