@@ -255,7 +255,7 @@ class MPU64180Device : public MPUDevice, private HD64180
 	// 直近の命令語
 	uint8 op {};
 
-	uint64 clock_nsec {};	// MPU クロック [nsec]
+	uint64 clock_tsec {};	// MPU クロック [tsec]
 
 	// 電源オンからの累積消費サイクル
 	uint64 used_cycle {};
@@ -322,6 +322,6 @@ class MPU64180Device : public MPUDevice, private HD64180
 	static std::vector<const char *> ionames;
 };
 
-static inline MPU64180Device *GetMPU64180Device() {
+inline MPU64180Device *GetMPU64180Device() {
 	return Object::GetObject<MPU64180Device>(OBJ_MPUXP);
 }
