@@ -8,6 +8,13 @@
 // MPU (MC68030/MC68040)
 //
 
+// ログレベル基準。
+// 1: 状態変化などの概要
+// 2: 命令などによる詳細
+// 3: メモリアクセスの概要
+// 4: メモリアクセスの詳細(MMU等)
+// 5: デバッガアクセスのデバッグ用
+
 #pragma once
 
 #include "mpu.h"
@@ -29,7 +36,7 @@ class m68040ATCEntry;
 class MPU680x0Device : public MainMPUDevice
 {
 	using inherited = MainMPUDevice;
-	friend class m68030MMU;
+	friend class m68030PageTableOp;
 
  public:
 	MPU680x0Device();
@@ -57,8 +64,7 @@ class MPU680x0Device : public MainMPUDevice
 	bool IsSuper() const	{ return reg.s; }
 	bool IsMaster() const	{ return reg.m; }
 
-	// 現在アクセス中の論理アドレス、物理アドレスを取得。
-	uint32 GetLaddr() const override { return bus.laddr.Addr(); }
+	// 現在アクセス中の物理アドレスを取得。
 	uint32 GetPaddr() const override { return bus.paddr.Addr(); }
 
 	// 割り込みレベルが変わったことを MPU に通知
@@ -486,6 +492,11 @@ class MPU68030Device : public MPU680x0Device
 	busaddr TranslatePeek(busaddr laddr) override;
 	void CalcStat() override;
 
+	// fc に対する文字列("UD"とか)を返す。
+	static const char *FCstr(uint fc_) {
+		return &fcstr[fc_ * 4];
+	}
+
  private:
 	// リセット
 	void ResetCache() override;
@@ -503,6 +514,8 @@ class MPU68030Device : public MPU680x0Device
 	void ops_mmu30_pflush_ea();
 	void ops_mmu30_pload();
 	void ops_mmu30_ptest();
+	uint32 ptest_atc(const busaddr);
+	uint32 ptest_search(uint level, const busaddr, uint rn);
 
 	// バスアクセス
 	uint32 fetch_2() override;
@@ -522,7 +535,10 @@ class MPU68030Device : public MPU680x0Device
 	// MMU
 	bool TranslateRead() override;
 	bool TranslateWrite() override;
-	bool CheckTT();
+	busaddr TranslateRead(const busaddr laddr);
+	busaddr TranslateWrite(const busaddr laddr);
+	busaddr TTMatch(const busaddr laddr) const;
+	void PageTableSearch(const busaddr laddr, m68030ATCLine *);
 
 	bool SetSRP(uint32, uint32);
 	bool SetCRP(uint32, uint32);
@@ -549,6 +565,8 @@ class MPU68030Device : public MPU680x0Device
 	// キャッシュ
 	std::unique_ptr<m68030Cache> icache /*{}*/;
 	std::unique_ptr<m68030Cache> dcache /*{}*/;
+
+	static const char fcstr[];
 };
 
 class MPU68040Device : public MPU680x0Device
@@ -594,7 +612,7 @@ class MPU68040Device : public MPU680x0Device
 	// MMU
 	bool TranslateRead() override;
 	bool TranslateWrite() override;
-	m68040TT *CheckTT(std::array<std::unique_ptr<m68040TT>, 2>&) const;
+	m68040TT *TTMatch(std::array<std::unique_ptr<m68040TT>, 2>&) const;
 	bool LookupATC(m68040ATC&);
 	void Search(m68040ATCEntry *);
 	uint32 PeekDesc(uint32 base, uint32 idx);
@@ -610,7 +628,7 @@ class MPU68040Device : public MPU680x0Device
 	DECLARE_MONITOR_SCREEN(MonitorScreenATC);
 	int MonitorScreenMMU(TextScreen&, int, m68kreg&);
 	void MonitorScreenTT(TextScreen&, int x, int y, const char *, uint32);
-	void MonitorScreenATC1(TextScreen&, int, const m68040ATC *);
+	void MonitorScreenATC1(TextScreen&, int, bool, const m68040ATC *);
 
 	// FPU
 	void MonitorScreenFPU40(TextScreen&, int y, const FPU40&);
