@@ -32,6 +32,6 @@ class NewsfbDevice : public Device
 	Monitor *monitor {};
 };
 
-static inline NewsfbDevice *GetNewsfbDevice() {
+inline NewsfbDevice *GetNewsfbDevice() {
 	return Object::GetObject<NewsfbDevice>(OBJ_NEWSFB);
 }
