@@ -85,7 +85,7 @@ NewsIODevice::NewsIODevice()
 	src_screen.Init(75, 64, TextScreen::Ring);
 
 	monitor = gMonitorManager->Regist(ID_SUBWIN_NEWSIO, this);
-	monitor->func = ToMonitorCallback(&NewsIODevice::MonitorUpdate);
+	monitor->SetCallback(&NewsIODevice::MonitorScreen);
 	monitor->SetSize(src_screen.GetCol(), 1 + 32);
 	monitor->SetMaxHeight(1 + 64);
 }
@@ -196,11 +196,11 @@ NewsIODevice::InitMonitor()
 	}
 
 	// 下半分は NewsCtlr で処理。
-	newsctlr->MonitorUpdateNewsCtlr(screen, y);
+	newsctlr->MonitorScreenNewsCtlr(screen, y);
 }
 
 void
-NewsIODevice::MonitorUpdate(Monitor *, TextScreen& screen)
+NewsIODevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	// pos が表示開始位置(0-)
 	int pos = (int)screen.userdata;
