@@ -53,6 +53,6 @@ class NewsIODevice : public IODevice
 	TextScreen src_screen {};
 };
 
-static inline NewsIODevice *GetNewsIODevice() {
+inline NewsIODevice *GetNewsIODevice() {
 	return Object::GetObject<NewsIODevice>(OBJ_NEWSIO);
 }
