@@ -64,6 +64,6 @@ class PEDECDevice : public InterruptDevice
 	InterruptDevice *interrupt {};
 };
 
-static inline PEDECDevice *GetPEDECDevice() {
+inline PEDECDevice *GetPEDECDevice() {
 	return Object::GetObject<PEDECDevice>(OBJ_PEDEC);
 }
