@@ -133,6 +133,6 @@ class X68030PowerDevice : public PowerDevice
 	bool alarm_out {};
 };
 
-static inline PowerDevice *GetPowerDevice() {
+inline PowerDevice *GetPowerDevice() {
 	return Object::GetObject<PowerDevice>(OBJ_POWER);
 }
