@@ -177,7 +177,7 @@ PROMDevice::InitLuna1()
 	}
 
 	// XXX アクセスウェイトは未調査。とりあえず RAM と同程度にしておく
-	wait = busdata::Wait(1 * mpu->GetClock_nsec());
+	wait = busdata::Wait(1 * mpu->GetClock_tsec());
 
 	// ROM バージョンを確認。確認されてるのは
 	// V4.02 (Wed Oct 12 17:07:11 1988)
@@ -262,7 +262,7 @@ PROMDevice::InitLuna88k()
 	}
 
 	// XXX アクセスウェイトは未調査。とりあえず RAM と同程度にしておく
-	wait = busdata::Wait(3 * mpu->GetClock_nsec());
+	wait = busdata::Wait(3 * mpu->GetClock_tsec());
 
 	// ROM バージョンを照合。どこかに日付が埋まってるっぽい。
 	//
