@@ -85,8 +85,8 @@ class SCCDevice : public MPSCCDevice
 	DECLARE_MONITOR_SCREEN(MonitorScreen);
 	void MonitorScreenCh(TextScreen&, int ch, int xbase, int ybase);
 
-	// PCLK (入力クロック) の時間表現
-	uint64 pclk_ns {};
+	// PCLK (入力クロック) の時間表現 [tsec]
+	uint64 pclk_tsec {};
 
 	Keyboard *keyboard {};
 
@@ -94,6 +94,6 @@ class SCCDevice : public MPSCCDevice
 	static const char * const rrnames[32];
 };
 
-static inline SCCDevice *GetSCCDevice() {
+inline SCCDevice *GetSCCDevice() {
 	return Object::GetObject<SCCDevice>(OBJ_MPSCC);
 }
