@@ -100,7 +100,7 @@ class SCSIBus : public Device
 	// 次の REQ アサートの前に指定のウェイトを入れる
 	// (シークタイムなどを簡易的に再現するため)。
 	// ウェイトは一度適用されると 0 に戻る。
-	void SetOneshotReqWait(uint64 nsec) { req_wait += nsec; }
+	void SetOneshotReqWait(uint64 tsec) { req_wait += tsec; }
 
  private:
 	void BusFree(uint id);
@@ -130,7 +130,7 @@ class SCSIBus : public Device
 	// 転送速度をここで律速させている。
 	uint64 last_req_time {};
 
-	// 次の REQ アサートに入れるウェイト [nsec]
+	// 次の REQ アサートに入れるウェイト [tsec]
 	uint64 req_wait {};
 
 	// 実際のバスではそんなことはないが、ここではバスがイニシエータと
