@@ -334,6 +334,6 @@ class SPCDevice : public IODevice
 	Monitor *monitor {};
 };
 
-static inline SPCDevice *GetSPCDevice() {
+inline SPCDevice *GetSPCDevice() {
 	return Object::GetObject<SPCDevice>(OBJ_SPC);
 }
