@@ -102,7 +102,7 @@ Syncer::StartTime()
 	// Restart() は経過時間をリセットしてからタイマーを開始の意。
 	realtime.Restart();
 
-	rtime = realtime.Elapsed_nsec();
+	rtime = nsec_to_tsec(realtime.Elapsed_nsec());
 	rtime_epoch = rtime;
 	vtime_epoch = scheduler->GetVirtTime();
 
@@ -276,7 +276,7 @@ void
 Syncer::DoSync()
 {
 	// 実時間をここで更新
-	rtime = realtime.Elapsed_nsec();
+	rtime = nsec_to_tsec(realtime.Elapsed_nsec());
 	DPRINTF("Sync begin rtime=%s\n", SecToStr(rtime).c_str());
 
 	// 統計情報
@@ -304,7 +304,7 @@ Syncer::DoSync()
 
 			// スリープしすぎた時間を計測。
 			// この時間にはスリープ時間を計算するための時間も含む。
-			rtime = realtime.Elapsed_nsec();
+			rtime = nsec_to_tsec(realtime.Elapsed_nsec());
 			DPRINTF("Sync wakeup rtime=%s\n", SecToStr(rtime).c_str());
 			uint64 realslept = rtime - prev;
 			if (realslept > diff) {
@@ -374,9 +374,8 @@ Syncer::PutlogRealtime()
 	uint64 vtime = scheduler->GetVirtTime();
 
 	// 電源オン時からここまでの時間を表示するだけでリセット等はしない。
-	putlog(0, "Elapsed since power-on: %u.%03u sec, %6.2f%%",
-		(uint)(rtime / (1000 * 1000 * 1000)),
-		(uint)((rtime / (1000 * 1000)) % 1000),
+	putlog(0, "Elapsed since power-on: %.3f sec, %6.2f%%",
+		(double)rtime / 1_sec,
 		(double)vtime / rtime * 100);
 
 #if 0
@@ -385,7 +384,8 @@ Syncer::PutlogRealtime()
 	for (const auto e : events) {
 		sum += e->count;
 	}
-	putlog(0, "%lu events done, %6.3fM/sec", sum, (double)sum / rtime * 1000);
+	putlog(0, "%lu events done, %6.3fM/sec", sum,
+		(double)sum / rtime * 1_usec);
 #endif
 }
 
