@@ -171,7 +171,7 @@ SysCtlrDevice::SysCtlrDevice()
 	intmap_status = IntmapSentinel;
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_INTERRUPT, this);
-	monitor->func = ToMonitorCallback(&SysCtlrDevice::MonitorUpdate);
+	monitor->SetCallback(&SysCtlrDevice::MonitorScreen);
 }
 
 // デストラクタ
@@ -360,7 +360,7 @@ SysCtlrDevice::Peek1(uint32 addr)
 }
 
 void
-SysCtlrDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+SysCtlrDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int y;
 
