@@ -54,6 +54,6 @@ class V68kIODevice : public IODevice
 	std::array<IODevice*, 128> viotable {};
 };
 
-static inline V68kIODevice *GetV68kIODevice() {
+inline V68kIODevice *GetV68kIODevice() {
 	return Object::GetObject<V68kIODevice>(OBJ_V68KIO);
 }
