@@ -66,7 +66,7 @@ VirtIOBlockDevice::VirtIOBlockDevice(uint slot_, uint id_)
 	msgid = MessageID::VIRTIO_BLOCK_DONE(id);
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_VIRTIO_BLOCK(id), this);
-	monitor->func = ToMonitorCallback(&VirtIOBlockDevice::MonitorUpdate);
+	monitor->SetCallback(&VirtIOBlockDevice::MonitorScreen);
 	monitor->SetSize(MONITOR_WIDTH, 2 + 4 * 1 + num_max + 3);
 }
 
@@ -167,17 +167,17 @@ VirtIOBlockDevice::LoadDisk(const std::string& pathname_)
 }
 
 void
-VirtIOBlockDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+VirtIOBlockDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int y = 0;
 
 	screen.Clear();
 
-	y = MonitorUpdateDev(screen, y);
+	y = MonitorScreenDev(screen, y);
 	y++;
-	y = MonitorUpdateVirtQueue(screen, y, vqueues[0]);
+	y = MonitorScreenVirtQueue(screen, y, vqueues[0]);
 	y++;
-	y = MonitorUpdateVirtQDesc(screen, y, vqueues[0]);
+	y = MonitorScreenVirtQDesc(screen, y, vqueues[0]);
 }
 
 // ディスクリプタを一つ処理する。
