@@ -202,9 +202,10 @@ VirtIONetDevice::ProcessDesc(VirtIOReq& req)
 		num_buffers);
 
 	NetPacket tx_packet;
-	uint32 len = std::min((uint32)tx_packet.size(), req.rremain());
-	uint32 rest = ReqReadRegion(req, tx_packet.data(), len);
-	tx_packet.length = len - rest;
+	uint32 len = req.rremain();
+	tx_packet.Resize(len);
+	uint32 rest = ReqReadRegion(req, tx_packet.Data(), len);
+	tx_packet.Resize(len - rest);
 
 	hostnet->Tx(tx_packet);
 }
@@ -257,7 +258,7 @@ VirtIONetDevice::RxEvent(Event *ev)
 	}
 
 	// ディスクリプタに空きが出来たので、ホストキューから1パケット取り出す。
-	assert(rx_packet.length == 0);
+	assert(rx_packet.Length() == 0);
 	if (hostnet->Rx(&rx_packet) == false) {
 		// 取り出せなくなったら、ここでイベントループを終了。
 		rx_packet.Clear();
@@ -265,7 +266,7 @@ VirtIONetDevice::RxEvent(Event *ev)
 		return;
 	}
 
-	putlog(2, "%s: %u bytes from host queue", __func__, rx_packet.length);
+	putlog(2, "%s: %u bytes from host queue", __func__, rx_packet.Length());
 
 	// rx_packet が埋まって、空きディスクリプタがあるので受信処理へ。
 	Rx(q);
@@ -279,15 +280,15 @@ VirtIONetDevice::RxEvent(Event *ev)
 void
 VirtIONetDevice::Rx(VirtQueue *q)
 {
-	assert(rx_packet.length != 0);
+	assert(rx_packet.Length() != 0);
 	assert(q->last_avail_idx != ReadLE16(q->driver + 2));
 
 	// XXX どこでやるのがいいか
 	// VirtIO は FCS を含まない 1514 バイトが上限と決まっているが、
 	// HostNet の下の受信ドライバが FCS を含めているかどうかが分からない。
 	// 仕方ないので 1514 バイトを超える時だけ取り除く…。
-	if (rx_packet.length > 1514) {
-		rx_packet.length = 1514;
+	if (rx_packet.Length() > 1514) {
+		rx_packet.Resize(1514);
 	}
 
 	VirtIOReq req;
@@ -303,7 +304,7 @@ VirtIONetDevice::Rx(VirtQueue *q)
 	uint32 len = 0;
 	for (; nseg < req.wbuf.size(); nseg++) {
 		len += req.wbuf[nseg].len;
-		if (len >= sizeof(hdr) + rx_packet.length) {
+		if (len >= sizeof(hdr) + rx_packet.Length()) {
 			break;
 		}
 	}
@@ -313,7 +314,7 @@ VirtIONetDevice::Rx(VirtQueue *q)
 	ReqWriteRegion(req, (const uint8 *)&hdr, sizeof(hdr));
 
 	// パケット本体を書き込む。
-	ReqWriteRegion(req, rx_packet.data(), rx_packet.length);
+	ReqWriteRegion(req, rx_packet.Data(), rx_packet.Length());
 
 	CommitDesc(req);
 
