@@ -24,8 +24,9 @@
 #include "hostwindrv.h"
 #include "mainbus.h"
 #include "mpu680x0.h"
+#include "mytime.h"
 #include <fcntl.h>
-#include <sys/time.h>
+#include <time.h>
 #include <algorithm>
 
 // コンストラクタ
@@ -1757,10 +1758,7 @@ FilesBuf::Init(uint32 key_, HostWindrv *host_)
 void
 FilesBuf::UpdateATime()
 {
-	struct timeval tv;
-
-	gettimeofday(&tv, NULL);
-	atime = (uint64)tv.tv_sec * 1000'000 + (uint64)tv.tv_usec;
+	atime = get_hosttime_usec();
 }
 
 
@@ -2301,10 +2299,7 @@ VDir::MatchName(const std::string& name, bool want_exist) const
 void
 VDir::UpdateATime()
 {
-	struct timeval tv;
-
-	gettimeofday(&tv, NULL);
-	atime = (uint64)tv.tv_sec * 1000'000 + (uint64)tv.tv_usec;
+	atime = get_hosttime_usec();
 }
 
 
