@@ -88,6 +88,6 @@ class X68kIODevice : public MainbusBaseDevice
 	Monitor *area_monitor {};
 };
 
-static inline X68kIODevice *GetX68kIODevice() {
+inline X68kIODevice *GetX68kIODevice() {
 	return Object::GetObject<X68kIODevice>(OBJ_X68KIO);
 }
