@@ -119,9 +119,9 @@ X68030Keyboard::MonitorScreen(Monitor *, TextScreen& screen)
 	// キーリピート
 	screen.Puts(0, y, "Key Repeat:");
 	screen.Print(12, y++, "Delay  $%x(%4umsec)",
-		rept_delay_data, (uint)(rept_delay / 1_msec));
+		rept_delay_data, (uint)tsec_to_msec(rept_delay));
 	screen.Print(12, y++, "Repeat $%x(%4umsec)",
-		rept_time_data, (uint)(rept_time / 1_msec));
+		rept_time_data, (uint)tsec_to_msec(rept_time));
 
 	// マウス
 	int mx = mouse_x;
@@ -440,14 +440,14 @@ X68030Keyboard::Command(uint32 data)
 		rept_delay_data = data & 15;
 		rept_delay = 200_msec + rept_delay_data * 100_msec;
 		putlog(1, "Command Repeat Delay %u (%u msec)", rept_delay_data,
-			(uint)(rept_delay / 1_msec));
+			(uint)tsec_to_msec(rept_delay));
 
 	} else if (data < 0x80) {
 		// $70-$7f リピート間隔
 		rept_time_data = data & 15;
 		rept_time = 30_msec + rept_time_data * rept_time_data * 5_msec;
 		putlog(1, "Command Repeat time  %d (%u msec)", rept_time_data,
-			(uint)(rept_time / 1_msec));
+			(uint)tsec_to_msec(rept_time));
 
 	} else {
 		// $80-$ff LED 制御
