@@ -52,7 +52,7 @@ class X68030Keyboard : public Keyboard
 	void Ready();
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// キーボードの接続と取り外し
 	void MDConnect() override;
