@@ -74,8 +74,7 @@ WXDipswWindow::WXDipswWindow(wxWindow *parent)
 		swctl.push_back(ctl);
 
 		// スクロールイベントをこっちに接続
-		ctl->Connect(NONO_EVT_SCROLL,
-			wxScrollEventHandler(WXDipswWindow::OnScroll), NULL, this);
+		ctl->Bind(NONO_EVT_SCROLL, &WXDipswWindow::OnScroll, this);
 	}
 
 	// DIPSW ボックス
