@@ -21,14 +21,13 @@ class WXMemdumpWindow : public WXSubWindow
 	using inherited = WXSubWindow;
  public:
 	WXMemdumpWindow(wxWindow *parent, int monid);
-	virtual ~WXMemdumpWindow() override;
+	~WXMemdumpWindow() override;
 
 	void FontChanged() override;
-	void Fit() override;
 	bool Layout() override;
 
  private:
-	wxSize DoSizeHints();
+	bool GetMySizeHints(wxSize *, wxSize *, wxSize *, wxSize *) override;
 
 	// テキスト入力イベント
 	void OnTextEnter(wxCommandEvent& event);
@@ -81,12 +80,6 @@ class WXMemdumpWindow : public WXSubWindow
 	// メモリダンプ
 	MemdumpMonitor *memdump {};
 
-	// 前回のウィンドウマージン (クライアント領域の外側)
-	wxSize oldmargin {};
-
-	// 謎のリサイズ対策
-	bool layout_pass2 {};
-
 	// イベントテーブル
 	wxDECLARE_EVENT_TABLE();
 };
