@@ -67,8 +67,7 @@ WXLogSettingPanel::WXLogSettingPanel(wxWindow *parent)
 		buttons.push_back(btn);
 
 		// イベントを接続
-		btn->Connect(NONO_EVT_BUTTON,
-			wxCommandEventHandler(WXLogSettingPanel::OnButton), NULL, this);
+		btn->Bind(NONO_EVT_BUTTON, &WXLogSettingPanel::OnButton, this);
 	}
 
 	// Sizer 使わず自前でレイアウトする。
