@@ -25,13 +25,14 @@ class WXLogSettingPanel : public WXTextPanel
 	explicit WXLogSettingPanel(wxWindow *parent);
 	~WXLogSettingPanel() override;
 
-	bool Layout() override;
 	void FontChanged() override;
-	void Draw() override;
+	void Fit() override;
+	bool Layout() override;
 
  private:
 	inline int Col2PX(int col) const;
 	inline int Row2PY(int row) const;
+	void Draw() override;
 
 	void OnButton(wxCommandEvent&);
 
@@ -50,7 +51,4 @@ class WXLogSettingWindow : public WXSubWindow
  public:
 	explicit WXLogSettingWindow(wxWindow *);
 	~WXLogSettingWindow() override;
-
- private:
-	WXLogSettingPanel *panel {};
 };
