@@ -649,10 +649,10 @@ WXMainFrame::WXMainFrame(wxWindow *parent)
 	// 来た or 外れたことを示すので、wxFrame (というかたぶん wxTopLevelWindow)
 	// を継承している WXMainFrameに飛んでくるのだが、処理の都合上 WXMainView で
 	// 扱いたいので、そちらに回す。
-	Connect(wxEVT_ACTIVATE, wxActivateEventHandler(WXMainView::OnActivate),
-		NULL, mainview);
+	Bind(wxEVT_ACTIVATE, &WXMainView::OnActivate, mainview);
 
 	// ウィンドウ表示後に続きの処理をするための単発アイドルイベント。
+	// こっちは Disconnect() するので Bind() は使えない。
 	Connect(wxEVT_IDLE, wxIdleEventHandler(WXMainFrame::OnIdle));
 
 	// VM からの通知を接続
