@@ -77,8 +77,7 @@ WXMainView::WXMainView(wxWindow *parent)
 	}
 
 	// マウスモード変更イベント
-	Connect(NONO_EVT_MOUSEMODE,
-		wxCommandEventHandler(WXMainView::OnMouseMode), NULL, this);
+	Bind(NONO_EVT_MOUSEMODE, &WXMainView::OnMouseMode, this);
 
 	// VM からの通知を受け取る
 	WXUIMessage::Connect(UIMessage::RENDER, this,
