@@ -16,7 +16,7 @@ wxDECLARE_EVENT(NONO_EVT_MOUSEMODE, wxCommandEvent);
 
 class DumbKeyboard;
 class Keyboard;
-class Renderer;
+class VideoRenderer;
 
 class WXMainView : public wxPanel
 {
@@ -86,7 +86,7 @@ class WXMainView : public wxPanel
 
 	DumbKeyboard *dumbkbd {};
 	Keyboard *richkbd {};
-	Renderer *renderer {};
+	VideoRenderer *renderer {};
 
 	wxDECLARE_EVENT_TABLE();
 };
