@@ -40,6 +40,10 @@ enum {
 	IDGROUP_LOGSETTING,
 	IDGROUP_LOGSETTING_END = IDGROUP_LOGSETTING + 199,
 
+	// wxpagetablemonitor
+	IDGROUP_PAGETABLE,
+	IDGROUP_PAGETABLE_END = IDGROUP_PAGETABLE + 9,
+
 	// wxtvrammonitor
 	IDGROUP_TVRAM,
 	IDGROUP_TVRAM_END = IDGROUP_TVRAM + 9,
