@@ -65,12 +65,9 @@ WXSoftKeyPanel::WXSoftKeyPanel(wxWindow *parent,
 	// このパネルへのキー入力はメインビューへのキー入力と同じ。
 	auto mainframe = dynamic_cast<WXMainFrame*>(GetParent()->GetParent());
 	auto mainview = mainframe->GetMainView();
-	Connect(wxEVT_CHAR, wxCharEventHandler(WXMainView::OnChar), NULL,
-		mainview);
-	Connect(wxEVT_KEY_UP, wxKeyEventHandler(WXMainView::OnKeyUp), NULL,
-		mainview);
-	Connect(wxEVT_KEY_DOWN, wxKeyEventHandler(WXMainView::OnKeyDown), NULL,
-		mainview);
+	Bind(wxEVT_CHAR,     &WXMainView::OnChar,    mainview);
+	Bind(wxEVT_KEY_UP,   &WXMainView::OnKeyUp,   mainview);
+	Bind(wxEVT_KEY_DOWN, &WXMainView::OnKeyDown, mainview);
 
 	// VM からの通知を受け取る
 	WXUIMessage::Connect(UIMessage::KEYBOARD, this,
