@@ -204,12 +204,9 @@ WXStatusPanel::WXStatusPanel(wxWindow *parent)
 	// キー入力イベントは全部メインビューに飛ばす。
 	auto mainframe = dynamic_cast<WXMainFrame*>(GetParent());
 	auto mainview = mainframe->GetMainView();
-	Connect(wxEVT_KEY_UP, wxKeyEventHandler(WXMainView::OnKeyUp), NULL,
-		mainview);
-	Connect(wxEVT_KEY_DOWN, wxKeyEventHandler(WXMainView::OnKeyDown), NULL,
-		mainview);
-	Connect(wxEVT_CHAR, wxKeyEventHandler(WXMainView::OnChar), NULL,
-		mainview);
+	Bind(wxEVT_KEY_UP,   &WXMainView::OnKeyUp,   mainview);
+	Bind(wxEVT_KEY_DOWN, &WXMainView::OnKeyDown, mainview);
+	Bind(wxEVT_CHAR,     &WXMainView::OnChar,    mainview);
 
 	// VM からの通知を受け取る
 	WXUIMessage::Connect(UIMessage::SCSI_MEDIA_CHANGE, this,
